vcov.mcmc.list <-
function(object, ...)
{
    cov(as.matrix(object), ...)
}
